(function() {
	//エラー情報リスト
	var errMessageList = {
		"1"   : "FileError.NOT_FOUND_ERR" ,
		"2"   : "FileError.SECURITY_ERR" ,
		"3"   : "FileError.ABORT_ERR" ,
		"4"   : "FileError.NOT_READABLE_ERR" ,
		"5"   : "FileError.ENCODING_ERR" ,
		"6"   : "FileError.NO_MODIFICATION_ALLOWED_ERR" ,
		"7"   : "FileError.INVALID_STATE_ERR" ,
		"8"   : "FileError.SYNTAX_ERR" ,
		"9"   : "FileError.INVALID_MODIFICATION_ERR" ,
		"10"  : "FileError.QUOTA_EXCEEDED_ERR" ,
		"11"  : "FileError.TYPE_MISMATCH_ERR" ,
		"12"  : "FileError.PATH_EXISTS_ERR"
	};

	/*
	 * ファイル一覧取得
	 */
	getFileList = function() {
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, getFileListGotFS, getFileListError);
	}

	/*
	 * FileEntry取得
	 */
	function getFileListGotFS(fileSystem) {
		var directoryReader = fileSystem.root.createReader();
		directoryReader.readEntries(getFileListReadEntries, getFileListError);
	}

	/*
	 * ファイル一覧取得
	 */
	function getFileListReadEntries(entries) {
		var dump = "ファイル一覧を取得しました。\n";
		document.getElementById("dumpAreaFile").value = dump;

		for(var i = 0; i < entries.length; i++) {
			document.getElementById("dumpAreaFile").value += entries[i].name + (entries[i].isDirectory ? "/" : "") + "\n";
		}
	}

	/*
	 * ファイル一覧取得失敗時のcallback処理
	 */
	function getFileListError(error) {
		var dump = "ファイル一覧の取得に失敗しました。: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ディレクトリ作成
	 */
	mkdir = function() {
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, mkdirGotFS, mkdirError);
	}

	/*
	 * DirectoryEntry取得
	 */
	function mkdirGotFS(fileSystem) {
		fileSystem.root.getDirectory("newDir", {create: true, exclusive: false}, mkdirGetDirectory, mkdirError);
	}

	/*
	 * ディレクトリ作成成功時のcallback処理
	 */
	function mkdirGetDirectory(directoryEntry) {
		var dump = "ディレクトリを作成しました。\n";
		dump    += "name : "     + directoryEntry.name     + "\n";
		dump    += "fullPath : " + directoryEntry.fullPath + "\n";
		document.getElementById("dumpAreaFile").value = dump;
	}

	/*
	 * ディレクトリ作成失敗時のcallback処理
	 */
	function mkdirError(error) {
		var dump = "ディレクトリの作成に失敗しました: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ディレクトリ削除(Recursively)
	 */
	rmdirRecursively = function() {
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, rmdirRecursivelyGotFS, rmdirRecursivelyError);
	}

	/*
	 * DirectoryEntry取得(Recursively)
	 */
	function rmdirRecursivelyGotFS(fileSystem) {
		fileSystem.root.getDirectory("newDir", null, rmdirRecursivelyGetDirectory, rmdirRecursivelyError);
	}

	/*
	 * ディレクトリ削除(Recursively)
	 */
	function rmdirRecursivelyGetDirectory(directoryEntry) {
		directoryEntry.removeRecursively(removeRecursivelySuccess, rmdirRecursivelyError);
	}

	/*
	 * ディレクトリ削除成功時のcallback処理
	 */
	function removeRecursivelySuccess() {
		var dump = "ディレクトリを削除しました。\n";
		document.getElementById("dumpAreaFile").value = dump;
	}

	/*
	 * ディレクトリ削除失敗時のcallback処理
	 */
	function rmdirRecursivelyError(error) {
		var dump = "ディレクトリの削除に失敗しました: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ディレクトリ削除
	 */
	rmdir = function() {
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, rmdirGotFS, rmdirError);
	}

	/*
	 * DirectoryEntry取得
	 */
	function rmdirGotFS(fileSystem) {
		fileSystem.root.getDirectory("newDir", null, rmdirGetDirectory, rmdirError);
	}

	/*
	 * ディレクトリ削除
	 */
	function rmdirGetDirectory(directoryEntry) {
		directoryEntry.remove(removeSuccess, rmdirError);
	}

	/*
	 * ディレクトリ削除成功時のcallback処理
	 */
	function removeSuccess() {
		var dump = "ディレクトリを削除しました。\n";
		document.getElementById("dumpAreaFile").value = dump;
	}

	/*
	 * ディレクトリ削除失敗時のcallback処理
	 */
	function rmdirError(error) {
		var dump = "ディレクトリの削除に失敗しました: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ディレクトリ移動
	 */
	moveTo = function() {
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, moveToGotFS, moveToError);
	}

	/*
	 * DirectoryEntry取得
	 */
	function moveToGotFS(fileSystem) {
		fileSystem.root.getDirectory("newDir", null, moveToGetDirectory, moveToError);
	}

	/*
	 * ディレクトリ移動
	 */
	function moveToGetDirectory(directoryEntry) {
		var tmp = directoryEntry.fullPath;
		var parentPath = tmp.substring(0, tmp.lastIndexOf("/"));
		var parentName = parentPath.substring(parentPath.lastIndexOf("/") + 1);
		// var parentEntry = new DirectoryEntry(parentName, parentPath);
		var parentEntry = applican.filesystem.createDirectoryEntry(parentName, parentPath);

		//移動
		//パラメータ：
		//	entry : DirectoryEntry	移動先のディレクトリを指定します。
		//	name : String	移動時の新しい名前を指定します。（未指定の場合は現在の名前を利用します）
		//	successCallback : Function<DirectoryEntry>	ディレクトリを移動出来た場合にCallbackされます。
		//	errorCallback : Function<FileError>	ディレクトリの移動に失敗した場合にCallbackされます
		directoryEntry.moveTo(parentEntry, "newDir2", moveToSuccess, moveToError);
	}

	/*
	 * ディレクトリ移動成功時のcallback処理
	 */
	function moveToSuccess(entry) {
		var dump = "ディレクトリを移動しました。\n";
		dump    += "name : "     + entry.name     + "\n";
		dump    += "fullPath : " + entry.fullPath + "\n";
		document.getElementById("dumpAreaFile").value = dump;
	}

	/*
	 * ディレクトリ移動失敗時のcallback処理
	 */
	function moveToError(error) {
		var dump = "ディレクトリの移動に失敗しました: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ディレクトリコピー
	 */
	copyTo = function(){
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, copyToGotFS, copyToError);
	}

	/*
	 * DirectoryEntry取得
	 */
	function copyToGotFS(fileSystem) {
		fileSystem.root.getDirectory("newDir", null, copyToGetDirectory, copyToError);
	}

	/*
	 * ディレクトリコピー
	 */
	function copyToGetDirectory(directoryEntry) {
		var tmp = directoryEntry.fullPath;
		var parentPath = tmp.substring(0, tmp.lastIndexOf("/"));
		var parentName = parentPath.substring(parentPath.lastIndexOf("/") + 1);
		// var parentEntry = new DirectoryEntry(parentName, parentPath);
		var parentEntry = applican.filesystem.createDirectoryEntry(parentName, parentPath);

		// コピー
		//	パラメータ：
		//		entry : DirectoryEntry	移動先のディレクトリを指定します。
		//		name : String	コピー時の新しい名前を指定します。（未指定の場合は現在の名前を利用します）
		//		successCallback : Function<DirectoryEntry>	ディレクトリをコピー出来た場合にCallbackされます。
		//		errorCallback : Function<FileError>	ディレクトリのコピーに失敗した場合にCallbackされます。
		directoryEntry.copyTo(parentEntry, "newDir3", copyToSuccess, copyToError);
	}

	/*
	 * ディレクトリコピー成功時のcallback処理
	 */
	function copyToSuccess(entry) {
		var dump = "ディレクトリをコピーしました。\n";
		dump    += "name : "     + entry.name     + "\n";
		dump    += "fullPath : " + entry.fullPath + "\n";
		document.getElementById("dumpAreaFile").value = dump;
	}

	/*
	 * ディレクトリコピー失敗時のcallback処理
	 */
	function copyToError(error) {
		var dump = "ディレクトリのコピーに失敗しました: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ディレクトリtoURL
	 */
	toURL = function(){
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, toURLGotFS, toURLError);
	}

	/*
	 * DirectoryEntry取得
	 */
	function toURLGotFS(fileSystem) {
		fileSystem.root.getDirectory("newDir", null, toURLGetDirectory, toURLError);
	}

	/*
	 * ディレクトリのURLを取得する
	 */
	function toURLGetDirectory(directoryEntry) {
		var directoryURL = directoryEntry.toURL();
		var dump = "ディレクトリのURLを取得しました。\n";
		dump    += "URL : " + directoryURL + "\n";
		document.getElementById("dumpAreaFile").value = dump;
	}

	/*
	 * ディレクトリのURLを取得失敗時のcallback処理
	 */
	function toURLError(error) {
		var dump = "ディレクトリURLの取得に失敗しました: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * 親ディレクトリ取得
	 */
	getParent = function(){
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, getParentGotFS, getParentError);
	}

	/*
	 * 親ディレクトリのDirectoryEntryを取得
	 */
	function getParentGotFS(fileSystem) {
		fileSystem.root.getDirectory("newDir", null, getParentGetDirectory, getParentError);
	}

	/*
	 * 親ディレクトリを取得
	 */
	function getParentGetDirectory(directoryEntry) {
		directoryEntry.getParent(getParentSuccess, getParentError);
	}

	/*
	 * 親ディレクトリを取得成功時のcallback処理
	 */
	function getParentSuccess(entry) {
		var dump = "親ディレクトリを取得しました。\n";
		dump    += "name : "     + entry.name     + "\n";
		dump    += "fullPath : " + entry.fullPath + "\n";
		document.getElementById("dumpAreaFile").value = dump;
	}

	/*
	 * 親ディレクトリを取得失敗時のcallback処理
	 */
	function getParentError(error) {
		var dump = "親ディレクトリの取得に失敗しました: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/********************* イベント登録 *********************/
	document.addEventListener("deviceready", function() {
		// 「ファイル一覧」ボタン押下処理
		document.getElementById("getFileListBtn").addEventListener("touchend", getFileList, false);
		// 「ディレクトリ作成」ボタン押下処理
		document.getElementById("mkdirBtn").addEventListener("touchend", mkdir, false);
		// 「ディレクトリ削除(Recursively)」ボタン押下処理
		document.getElementById("rmdirRecursivelyBtn").addEventListener("touchend", rmdirRecursively, false);
		// 「ディレクトリ削除」ボタン押下処理
		document.getElementById("rmdirBtn").addEventListener("touchend", rmdir, false);
		// 「ディレクトリ移動」ボタン押下処理
		document.getElementById("moveToBtn").addEventListener("touchend", moveTo, false);
		// 「ディレクトリコピー」ボタン押下処理
		document.getElementById("copyToBtn").addEventListener("touchend", copyTo, false);
		// 「ディレクトリtoURL」ボタン押下処理
		document.getElementById("toURLBtn").addEventListener("touchend", toURL, false);
		// 「親ディレクトリ」ボタン押下処理
		document.getElementById("getParentBtn").addEventListener("touchend", getParent, false);
	}, false);
})();
