(function() {
	// エラー情報リスト
	var errMessageList = {
		"1"   : "FileError.NOT_FOUND_ERR" ,
		"2"   : "FileError.SECURITY_ERR" ,
		"3"   : "FileError.ABORT_ERR" ,
		"4"   : "FileError.NOT_READABLE_ERR" ,
		"5"   : "FileError.ENCODING_ERR" ,
		"6"   : "FileError.NO_MODIFICATION_ALLOWED_ERR" ,
		"7"   : "FileError.INVALID_STATE_ERR" ,
		"8"   : "FileError.SYNTAX_ERR" ,
		"9"   : "FileError.INVALID_MODIFICATION_ERR" ,
		"10"  : "FileError.QUOTA_EXCEEDED_ERR" ,
		"11"  : "FileError.TYPE_MISMATCH_ERR" ,
		"12"  : "FileError.PATH_EXISTS_ERR"
	};

	/*
	 * ファイル書き込み (永続的なストレージ)
	 */
	writeFile = function() {
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, writeFileGotFS, writeFileError);
	}

	/*
	 * FileEntry取得
	 */
	function writeFileGotFS(fileSystem) {
		var fileNm = document.getElementById("fileName").value;
		fileSystem.root.getFile(fileNm, {create: true, exclusive: false}, writeFileGotFileEntry, writeFileError);
	}

	/*
	 * FileWriter作成
	 */
	function writeFileGotFileEntry(fileEntry) {
		fileEntry.createWriter(writeFileGotFileWriter, writeFileError);
	}

	/*
	 * ファイルに内容を書き込み
	 */
	function writeFileGotFileWriter(writer) {
		var dump = "ファイルを書き込みました。\n";
		var outputContent = "some sample text 1";
		document.getElementById("dumpAreaFile").value = dump;
		//書き込み開始
		writer.onwritestart = function(evt) {
			document.getElementById("dumpAreaFile").value += "onwritestart\n";
		};
		//書き込み中断
		writer.onabort = function(evt) {
			document.getElementById("dumpAreaFile").value += "onabort\n";
		};
		//書き込み中
		writer.onwrite = function(evt) {
			document.getElementById("dumpAreaFile").value += "onwrite\n";
		};
		//書き込みエラー
		writer.onerror = function(evt) {
			document.getElementById("dumpAreaFile").value += "onerror\n";
		};
		//書き込み終了
		writer.onwriteend = function(evt) {
			document.getElementById("dumpAreaFile").value += "onwriteend\n";
			document.getElementById("dumpAreaFile").value += "ファイルの内容が '" + outputContent + "' となりました。\n";
		};
		//書き込み
		writer.write(outputContent);
	}

	/*
	 * ファイル書き込み失敗時のcallback処理
	 */
	function writeFileError(error) {
		var dump = "ファイルの書き込みに失敗しました。\n";
		dump    += "code : "    + error.code                 + "\n";
		dump    += "message : " + errMessageList[error.code] + "\n";
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ファイル書き込み (一時的なストレージ)
	 */
	writeFileToTempToTemp = function() {
		applican.requestFileSystem(LocalFileSystem.TEMPORARY, 0, writeFileToTempGotFS, writeFileToTempError);
	}

	/*
	 * FileEntry取得
	 */
	function writeFileToTempGotFS(fileSystem) {
		var fileNm = document.getElementById("fileName").value;
		fileSystem.root.getFile(fileNm, {create: true, exclusive: false}, writeFileToTempGotFileEntry, writeFileToTempError);
	}

	/*
	 * FileWriter作成
	 */
	function writeFileToTempGotFileEntry(fileEntry) {
		fileEntry.createWriter(writeFileToTempGotFileWriter, writeFileToTempError);
	}

	/*
	 * ファイルに内容を書き込み
	 */
	function writeFileToTempGotFileWriter(writer) {
		var dump = "ファイルを書き込みました。\n";
		var outputContent = "some sample text 2";
		document.getElementById("dumpAreaFile").value = dump;

		writer.onwriteend = function(evt) {
			document.getElementById("dumpAreaFile").value += "ファイルの内容が '" + outputContent + "' となりました。\n";
		};
		writer.write(outputContent);
	}

	/*
	 * ファイル書き込み失敗時のcallback処理
	 */
	function writeFileToTempError(error) {
		var dump = "ファイルの書き込みに失敗しました。\n";
		dump    += "code : "    + error.code                 + "\n";
		dump    += "message : " + errMessageList[error.code] + "\n";
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ファイル読み込み (永続的なストレージ)
	 */
	readFile = function() {
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, readFileGotFS, readFileError);
	}

	/*
	 * FileEntry取得
	 */
	function readFileGotFS(fileSystem) {
		var fileNm = document.getElementById("fileName").value;
		fileSystem.root.getFile(fileNm, null, readFileGotFileEntry, readFileError);
	}

	/*
	 * ファイル対象取得
	 */
	function readFileGotFileEntry(fileEntry) {
		fileEntry.file(readFileGotFile, readFileError);
	}

	/*
	 * ファイルを読み込み
	 */
	function readFileGotFile(file){
		var dump = "ファイルを読み込みました。\n";
		document.getElementById("dumpAreaFile").value = dump;

		//テキストとして読み込み
		readFileReadAsText(file);
		//データ URL として読み込み
		readFileReadDataUrl(file);
	}

	/*
	 * データ URL として読み込み
	 */
	function readFileReadDataUrl(file) {
		// var reader = new FileReader();
		var reader = applican.filesystem.createFileReader();
		reader.onloadend = function(evt) {
			var dump = "データURL：\n" + evt.target.result + "\n";
			document.getElementById("dumpAreaFile").value += dump;
		};
		reader.readAsDataURL(file);
	}

	/*
	 * テキストとして読み込み
	 */
	function readFileReadAsText(file) {
		// var reader = new FileReader();
		var reader = applican.filesystem.createFileReader();
		reader.onloadend = function(evt) {
			var dump = "テキスト内容：\n" + evt.target.result + "\n";
			document.getElementById("dumpAreaFile").value += dump;
		};
		reader.readAsText(file);
	}

	/*
	 * ファイル読み込み失敗時のcallback処理
	 */
	function readFileError(error) {
		var dump = "ファイルの読み込みに失敗しました。\n";
		dump    += "code : "    + error.code                 + "\n";
		dump    += "message : " + errMessageList[error.code] + "\n";
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ファイル読み込み (一時的なストレージ)
	 */
	readFileFromTemp = function() {
		applican.requestFileSystem(LocalFileSystem.TEMPORARY, 0, readFileFromTempGotFS, readFileFromTempError);
	}

	/*
	 * FileEntry取得
	 */
	function readFileFromTempGotFS(fileSystem) {
		var fileNm = document.getElementById("fileName").value;
		fileSystem.root.getFile(fileNm, null, readFileFromTempGotFileEntry, readFileFromTempError);
	}

	/*
	 * ファイル対象取得
	 */
	function readFileFromTempGotFileEntry(fileEntry) {
		fileEntry.file(readFileFromTempGotFile, readFileFromTempError);
	}

	/*
	 * ファイルを読み込み
	 */
	function readFileFromTempGotFile(file){
		var dump = "ファイルを読み込みました。\n";
		document.getElementById("dumpAreaFile").value = dump;

		//テキストとして読み込み
		readFileFromTempReadAsText(file);
		//データ URL として読み込み
		readFileFromTempReadDataUrl(file);
	}

	/*
	 * データ URL として読み込み
	 */
	function readFileFromTempReadDataUrl(file) {
		// var reader = new FileReader();
		var reader = applican.filesystem.createFileReader();
		reader.onloadend = function(evt) {
			var dump = "データURL：\n" + evt.target.result + "\n";
			document.getElementById("dumpAreaFile").value += dump;
		};
		reader.readAsDataURL(file);
	}

	/*
	 * テキストとして読み込み
	 */
	function readFileFromTempReadAsText(file) {
		// var reader = new FileReader();
		var reader = applican.filesystem.createFileReader();
		reader.onloadend = function(evt) {
			var dump = "テキスト内容：\n" + evt.target.result + "\n";
			document.getElementById("dumpAreaFile").value += dump;
		};
		reader.readAsText(file);
	}

	/*
	 * ファイル読み込み失敗時のcallback処理
	 */
	function readFileFromTempError(error) {
		var dump = "ファイルの読み込みに失敗しました。\n";
		dump    += "code : "    + error.code                 + "\n";
		dump    += "message : " + errMessageList[error.code] + "\n";
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ファイル削除
	 */
	deleteFile = function(){
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, deleteFileGotFS, deleteFileError);
	}

	/*
	 * FileEntry取得
	 */
	function deleteFileGotFS(fileSystem) {
		var fileNm = document.getElementById("fileName").value;
		fileSystem.root.getFile(fileNm, null, deleteFileGotFileEntry, deleteFileError);
	}

	/*
	 * ファイル削除
	 */
	function deleteFileGotFileEntry(fileEntry) {
		fileEntry.remove(deleteFileSuccess, deleteFileError);
	}

	/*
	 * ファイル削除成功時のcallback処理
	 */
	function deleteFileSuccess() {
		var dump = "ファイルを削除しました。\n";
		document.getElementById("dumpAreaFile").value = dump;
	}

	/*
	 * ファイル削除失敗時のcallback処理
	 */
	function deleteFileError(error) {
		var dump = "ファイルの削除に失敗しました: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ファイル移動
	 */
	moveTo = function() {
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, moveToGotFS, moveToError);
	}

	/*
	 * FileEntry取得
	 */
	function moveToGotFS(fileSystem) {
		var fileNm = document.getElementById("fileName").value;
		fileSystem.root.getFile(fileNm, null, moveToGotFileEntry, moveToError);
	}

	/*
	 * ファイル移動
	 */
	function moveToGotFileEntry(fileEntry) {
		var tmp = fileEntry.fullPath;
		var parentPath = tmp.substring(0, tmp.lastIndexOf("/"));
		var parentName = parentPath.substring(parentPath.lastIndexOf("/") + 1);
		// var parentEntry = new DirectoryEntry(parentName, parentPath);
		var parentEntry = applican.filesystem.createDirectoryEntry(parentName, parentPath);
		//ファイル移動
		fileEntry.moveTo(parentEntry, "readme2.txt", moveToSuccess, moveToError);
	}

	/*
	 * ファイル移動成功時のcallback処理
	 */
	function moveToSuccess(entry) {
		var dump = "ファイルを移動しました。\n";
		dump    += "name : "     + entry.name     + "\n";
		dump    += "fullPath : " + entry.fullPath + "\n";
		document.getElementById("dumpAreaFile").value = dump;
	}

	/*
	 * ファイル移動失敗時のcallback処理
	 */
	function moveToError(error) {
		var dump = "ファイルの移動に失敗しました: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ファイルコピー
	 */
	copyTo = function() {
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, copyToGotFS, copyToError);
	}

	/*
	 * FileEntry取得
	 */
	function copyToGotFS(fileSystem) {
		var fileNm = document.getElementById("fileName").value;
		fileSystem.root.getFile(fileNm, null, copyToGotFileEntry, copyToError);
	}

	/*
	 * ファイルコピー
	 */
	function copyToGotFileEntry(fileEntry) {
		var tmp = fileEntry.fullPath;
		var parentPath = tmp.substring(0, tmp.lastIndexOf("/"));
		var parentName = parentPath.substring(parentPath.lastIndexOf("/") + 1);
		// var parentEntry = new DirectoryEntry(parentName, parentPath);
		var parentEntry = applican.filesystem.createDirectoryEntry(parentName, parentPath);
		//コピー
		fileEntry.copyTo(parentEntry, "readme3.txt", copyToSuccess, copyToError);
	}

	/*
	 * ファイルコピー成功時のcallback処理
	 */
	function copyToSuccess(entry) {
		var dump = "ファイルをコピーしました。\n";
		dump    += "name : "     + entry.name     + "\n";
		dump    += "fullPath : " + entry.fullPath + "\n";
		document.getElementById("dumpAreaFile").value = dump;
	}

	/*
	 * ファイルコピー失敗時のcallback処理
	 */
	function copyToError(error) {
		var dump = "ファイルのコピーに失敗しました: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * ファイルtoURL
	 */
	fileToURL = function() {
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, toURLGotFS, toURLFail);
	}

	/*
	 * FileEntry取得
	 */
	function toURLGotFS(fileSystem) {
		var fileNm = document.getElementById("fileName").value;
		fileSystem.root.getFile(fileNm, null, toURLGotFileEntry, toURLFail);
	}

	/*
	 * ファイルのURLを取得する
	 */
	function toURLGotFileEntry(fileEntry) {
		var fileURL = fileEntry.toURL();
		var dump = "ファイルのURLを取得しました。\n";
		dump    += "URL : " + fileURL + "\n";
		document.getElementById("dumpAreaFile").value = dump;
	}

	/*
	 * ファイルのURLを取得失敗時のcallback処理
	 */
	function toURLFail(error) {
		var dump = "ファイルURLの取得に失敗しました: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/*
	 * 親ディレクトリパス取得
	 */
	getParent = function(){
		applican.requestFileSystem(LocalFileSystem.PERSISTENT, 0, getParentGotFS, getParentError);
	}

	/*
	 * 親ディレクトリのFileEntryを取得
	 */
	function getParentGotFS(fileSystem) {
		var fileNm = document.getElementById("fileName").value;
		fileSystem.root.getFile(fileNm, null, getParentGotFileEntry, getParentError);
	}

	/*
	 * 親ディレクトリを取得
	 */
	function getParentGotFileEntry(fileEntry) {
		fileEntry.getParent(getParentSuccess, getParentError);
	}

	/*
	 * 親ディレクトリを取得成功時のcallback処理
	 */
	function getParentSuccess(entry) {
		var dump = "親ディレクトリを取得しました。\n";
		dump    += "name : "     + entry.name     + "\n";
		dump    += "fullPath : " + entry.fullPath + "\n";
		document.getElementById("dumpAreaFile").value = dump;
	}

	/*
	 * 親ディレクトリを取得失敗時のcallback処理
	 */
	function getParentError(error) {
		var dump = "親ディレクトリの取得に失敗しました: \n" + error.code + " : " + errMessageList[error.code];
		document.getElementById("dumpAreaFile").value = dump;
		alert(dump);
	}

	/********************* イベント登録 *********************/
	document.addEventListener("deviceready", function() {
		// 「ファイル書き込み」ボタン押下処理
		document.getElementById("writeFileBtn").addEventListener("touchend", writeFile, false);
		// 「ファイル読み込み」ボタン押下処理
		document.getElementById("readFileBtn").addEventListener("touchend", readFile, false);
		// 「ファイル削除」ボタン押下処理
		document.getElementById("deleteFileBtn").addEventListener("touchend", deleteFile, false);
		// 「ファイル移動」ボタン押下処理
		document.getElementById("moveToBtn").addEventListener("touchend", moveTo, false);
		// 「ファイルコピー」ボタン押下処理
		document.getElementById("copyToBtn").addEventListener("touchend", copyTo, false);
		// 「ファイルtoURL」ボタン押下処理
		document.getElementById("fileToURLBtn").addEventListener("touchend", fileToURL, false);
		// 「親ディレクトリ」ボタン押下処理
		document.getElementById("getParentBtn").addEventListener("touchend", getParent, false);
		// 「ファイル書き込み(一時ストレージ)」ボタン押下処理
		document.getElementById("writeFileToTempToTempBtn").addEventListener("touchend", writeFileToTempToTemp, false);
		// 「ファイル読み込み(一時ストレージ)」ボタン押下処理
		document.getElementById("readFileFromTempBtn").addEventListener("touchend", readFileFromTemp, false);
	}, false);
})();
